package net.sergeych.crypto2

import kotlinx.serialization.Serializable

/**
 * Tag that identifies in some way the _decrypting key_. Is used in keyrings and
 * containers to fast find a proper key
 */
@Serializable
data class KeyId(val id: BinaryId, val kdp: KeyDerivationParams?=null ) {

    val tag: UByteArray by lazy { id.id }

    override fun equals(other: Any?): Boolean {
        if (this === other) return true
        if (other !is KeyId) return false
        return id == other.id
    }

    override fun hashCode(): Int {
        return id.hashCode()
    }

    override fun toString() = id.toString()

    constructor(magickNumber: KeysMagickNumber, data: UByteArray, kdp: KeyDerivationParams?=null)
    : this(BinaryId.createFromUBytes(magickNumber.number, data), kdp)
}